﻿using System;
using System.Windows.Forms;

namespace PhoneBook
{
    public partial class ContactView : UserControl
    {
        private readonly System.Drawing.Size defaultImageSize_ = new System.Drawing.Size(64, 64);

        public event EventHandler<SelectionChangedEventArgs> SelectionChangedEvent;

        public ContactView()
        {
            InitializeComponent();
            Init();
        }

        public long SelectedContact
        {
            get
            {
                return (long)dataGridViewContacts_.CurrentRow.Tag;
            }
        }

        public int ContactCount
        {
            get
            {
                return dataGridViewContacts_.Rows.Count;
            }
        }

        public void AddContact(PhoneBook.Model.Contact contact)
        {
            var fullName = contact.FirstName + " " + contact.LastName;
            var img = contact.Image == null ? (System.Drawing.Image)PhoneBook.Properties.Resources.def_contact : new System.Drawing.Bitmap(contact.Image, defaultImageSize_);
            var rowNum = dataGridViewContacts_.Rows.Add(fullName, contact.Phone, img);
            dataGridViewContacts_.Rows[rowNum].HeaderCell.Value = (rowNum + 1).ToString();
            dataGridViewContacts_.Rows[rowNum].Tag = contact.Id;
        }

        public void RemoveContact(long id)
        {
            foreach (DataGridViewRow row in dataGridViewContacts_.Rows)
            {
                if ((long)row.Tag == id)
                {
                    dataGridViewContacts_.Rows.Remove(row);
                    break;
                }
            }
        }

        public System.Drawing.Image RightImage
        {
            set
            {
                this.pictureBoxPreview_.Image = value;
            }
        }

        private void Init()
        {
            this.Dock = DockStyle.Fill;
            this.Anchor = AnchorStyles.Top | AnchorStyles.Right | AnchorStyles.Bottom | AnchorStyles.Left;
        }

        private void dataGridViewContacts_SelectionChanged(object sender, System.EventArgs e)
        {
            var currentRow = dataGridViewContacts_.CurrentRow;

            var localHandler = SelectionChangedEvent;

            if (currentRow!= null && localHandler != null)
            {
                localHandler(this, new SelectionChangedEventArgs((long)currentRow.Tag));
            }
        }
    }
}
