﻿using System;
using System.Windows.Forms;

namespace PhoneBook
{
    public partial class MainForm : Form
    {
        private ContactView contactView_ = new ContactView();
        private Model.Model model_;

        public MainForm(Model.Model model)
        {
            model_ = model;
            InitializeComponent();
            Init();
        }

        private void Init()
        {
            this.tableLayoutPanel1.Controls.Add(contactView_, 0, 0);

            InitEvents();

            var contactNumber = model_.ContactCount;

            if (contactNumber > 0)
            {
                var contacts = model_.SelectContacts(0, contactNumber - 1);

                foreach (var contact in contacts)
                {
                    contactView_.AddContact(contact);
                }
            }
            else
            {
                buttonRemove.Enabled = false;
            }
        }

        private void InitEvents()
        {
            model_.ContactAddedEvent += (obj, arg) =>
            {
                if (contactView_.InvokeRequired)
                {
                    contactView_.Invoke(new Action<Model.Contact>(contactView_.AddContact), arg.Contact);
                }
                else
                {
                    contactView_.AddContact(arg.Contact);
                }
            };

            model_.ContactRemovedEvent += (obj, arg) =>
            {
                if (contactView_.InvokeRequired)
                {
                    contactView_.Invoke(new Action<long>(contactView_.RemoveContact), arg.ContactId);
                }
                else
                {
                    contactView_.RemoveContact(arg.ContactId);
                }
            };

            contactView_.SelectionChangedEvent += (obj, arg) =>
            {
                var contact = model_.SelectContact(arg.ContactId);

                if (contact != null)
                {
                    contactView_.RightImage = contact.Image;
                }
            };
        }

        private void buttonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                var form = new NewContactForm();

                if (form.ShowDialog(this) == DialogResult.OK)
                {
                    var contact = new Model.Contact { FirstName = form.FirstName, LastName = form.LastName, Phone = form.PhoneNumber, Image = form.Image };
                    model_.AddContact(contact);
                }
            }
            catch (Exception ex)
            {
                HandleException(ex);
            }
        }

        private void buttonRemove_Click(object sender, EventArgs e)
        {
            try
            {
                var contactId = contactView_.SelectedContact;
                model_.RemoveContact(contactId);
                buttonRemove.Enabled = model_.ContactCount != 0;
            }
            catch (Exception ex)
            {
                HandleException(ex);
            }
        }

        private static void HandleException(Exception e)
        {
            System.Diagnostics.Trace.TraceError(e.ToString());
            MessageBox.Show(e.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
}
